==> haskell-neat-interpolation-0.5.1.3-104-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-neat-interpolation.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 neat-interpolation
version:              0.5.1.3
visibility:           public
id:                   neat-interpolation-0.5.1.3-GUvpRXxd417Jc6sdz222af
key:                  neat-interpolation-0.5.1.3-GUvpRXxd417Jc6sdz222af
license:              MIT
copyright:            (c) 2013, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/neat-interpolation
synopsis:
    A quasiquoter for neat and simple multiline text interpolation

description:
    A quasiquoter for producing Text values with support for
    a simple interpolation of input values.
    It removes the excessive indentation from the input and
    accurately manages the indentation of all lines of the interpolated variables.

category:             String, QuasiQuotes
abi:                  86ff568074c017950e439198ab1a9445
exposed:              True
exposed-modules:      NeatInterpolation
hidden-modules:
    NeatInterpolation.Parsing NeatInterpolation.Prelude
    NeatInterpolation.String

import-dirs:          /usr/lib/ghc-9.0.2/site-local/neat-interpolation-0.5.1.3
library-dirs:         /usr/lib/ghc-9.0.2/site-local/neat-interpolation-0.5.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-neat-interpolation
hs-libraries:         HSneat-interpolation-0.5.1.3-GUvpRXxd417Jc6sdz222af
depends:
    base-4.15.1.0 megaparsec-9.3.0-IsOTupFw4JPDV46Jn1LcDz
    template-haskell-2.17.0.0 text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-neat-interpolation/html/neat-interpolation.haddock

haddock-html:         /usr/share/doc/haskell-neat-interpolation/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-neat-interpolation-0.5.1.3-116-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-neat-interpolation.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 neat-interpolation
version:              0.5.1.3
visibility:           public
id:                   neat-interpolation-0.5.1.3-JtkCA2ZIFLfAyxz4J1iu5A
key:                  neat-interpolation-0.5.1.3-JtkCA2ZIFLfAyxz4J1iu5A
license:              MIT
copyright:            (c) 2013, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/neat-interpolation
synopsis:
    A quasiquoter for neat and simple multiline text interpolation

description:
    A quasiquoter for producing Text values with support for
    a simple interpolation of input values.
    It removes the excessive indentation from the input and
    accurately manages the indentation of all lines of the interpolated variables.

category:             String, QuasiQuotes
abi:                  cda5c5a1c41c2d5c69f749e029b9b217
exposed:              True
exposed-modules:      NeatInterpolation
hidden-modules:
    NeatInterpolation.Parsing NeatInterpolation.Prelude
    NeatInterpolation.String

import-dirs:          /usr/lib/ghc-9.0.2/site-local/neat-interpolation-0.5.1.3
library-dirs:         /usr/lib/ghc-9.0.2/site-local/neat-interpolation-0.5.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-neat-interpolation
hs-libraries:         HSneat-interpolation-0.5.1.3-JtkCA2ZIFLfAyxz4J1iu5A
depends:
    base-4.15.1.0 megaparsec-9.3.0-wNnyPWEpx79AooHESUf3J
    template-haskell-2.17.0.0 text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-neat-interpolation/html/neat-interpolation.haddock

haddock-html:         /usr/share/doc/haskell-neat-interpolation/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
